# Copyright 2019 The Abseil Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Python 2/3 compatibility module for collections.abc."""

from __future__ import absolute_import
from __future__ import division
from __future__ import print_function

import six

# pylint: disable=g-importing-member
# pylint: disable=unused-import
if six.PY3:
  from collections import abc
else:
  import collections as abc
